@@ -7,6 +7,7 @@ In this version of the implementation, we allow for batch sizes of arbitrary siz
 """
 from typing import Tuple, Union, Dict, Optional, List
 import tensorflow as tf
+from userinput.utils import must_be_in_set
 from tensorflow.python.ops import embedding_ops  # pylint: disable=import-error,no-name-in-module
 from tensorflow.keras.layers import Dropout, Layer, Dense  # pylint: disable=import-error,no-name-in-module
 from embiggen.layers.tensorflow.l2_norm import L2Norm
@@ -15,10 +16,13 @@ from embiggen.layers.tensorflow.l2_norm import L2Norm
 class GraphConvolution(Layer):
     """Layer implementing graph convolution layer."""
 
+    available_combiner = ["mean", "sqrtn", "sum"]
+
     def __init__(
         self,
         units: int,
         activation: str = "relu",
+        combiner: str = "mean",
         dropout_rate: Optional[float] = 0.5,
         apply_norm: bool = False,
         **kwargs: Dict
@@ -27,18 +31,28 @@ class GraphConvolution(Layer):
 
         Parameters
         ----------------------
-        units: int,
+        units: int
             The dimensionality of the output space (i.e. the number of output units).
-        activation: str = "relu",
+        activation: str = "relu"
             Activation function to use. If you don't specify anything, relu is used.
-        dropout_rate: Optional[float] = 0.5,
+        combiner: str = "mean"
+            A string specifying the reduction op.
+            Currently "mean", "sqrtn" and "sum" are supported. 
+            "sum" computes the weighted sum of the embedding results for each row.
+            "mean" is the weighted sum divided by the total weight.
+            "sqrtn" is the weighted sum divided by the square root of the sum of the squares of the weights.
+            Defaults to mean.
+        dropout_rate: Optional[float] = 0.5
             Float between 0 and 1. Fraction of the input units to drop.
             If the provided value is either zero or None the dropout rate
             is not applied.
-        **kwargs: Dict,
+        **kwargs: Dict
             Kwargs to pass to the parent Layer class.
         """
         super().__init__(**kwargs)
+        combiner = must_be_in_set(
+            combiner, self.available_combiner, "combiner")
+        self._combiner = combiner
         self._units = units
         self._activation = activation
         if dropout_rate == 0.0:
@@ -46,8 +60,8 @@ class GraphConvolution(Layer):
         self._dropout_rate = dropout_rate
         self._apply_norm = apply_norm
         self._dense_layers = []
-        self._dropout_layer = None
-        self._l2_norm = None
+        self._dropout_layers = []
+        self._l2_norms = []
 
     def build(self, input_shape) -> None:
         """Build the Graph Convolution layer.
@@ -70,6 +84,7 @@ class GraphConvolution(Layer):
                 "has a single element. It should contain exactly two elements, "
                 "the adjacency matrix and the node features."
             )
+
         for node_feature_shape in input_shape[1:]:
             dense_layer = Dense(
                 units=self._units,
@@ -78,17 +93,19 @@ class GraphConvolution(Layer):
             dense_layer.build(node_feature_shape)
             self._dense_layers.append(dense_layer)
 
-        if self._dropout_rate is not None:
-            self._dropout_layer = Dropout(self._dropout_rate)
-            self._dropout_layer.build(node_feature_shape)
-        else:
-            self._dropout_layer = lambda x: x
+            if self._dropout_rate is not None:
+                dropout_layer = Dropout(self._dropout_rate)
+                dropout_layer.build(node_feature_shape)
+            else:
+                def dropout_layer(x): return x
+            self._dropout_layers.append(dropout_layer)
 
-        if self._apply_norm:
-            self._l2_norm = L2Norm()
-            self._l2_norm.build(node_feature_shape)
-        else:
-            self._l2_norm = lambda x: x
+            if self._apply_norm:
+                l2_norm = L2Norm()
+                l2_norm.build((self._units,))
+            else:
+                def l2_norm(x): return x
+            self._l2_norms.append(l2_norm)
 
         super().build(input_shape)
 
@@ -111,14 +128,16 @@ class GraphConvolution(Layer):
         )
 
         return [
-            self._l2_norm(dense(embedding_ops.embedding_lookup_sparse_v2(
-                self._dropout_layer(node_feature),
+            dense(embedding_ops.embedding_lookup_sparse_v2(
+                node_feature,
                 ids,
                 adjacency,
-                combiner='mean'
-            )))
-            for dense, node_feature in zip(
+                combiner=self._combiner
+            ))
+            for dense, dropout, l2_norm, node_feature in zip(
                 self._dense_layers,
+                self._dropout_layers,
+                self._l2_norms,
                 node_features
             )
         ]
